# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/sampling.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v1/sampling.proto\x12 systemathics.apis.type.shared.v1*\xc0\x01\n\x08Sampling\x12\x18\n\x14SAMPLING_UNSPECIFIED\x10\x00\x12\x17\n\x13SAMPLING_ONE_MINUTE\x10\x01\x12\x18\n\x14SAMPLING_FIVE_MINUTE\x10\x02\x12\x17\n\x13SAMPLING_TEN_MINUTE\x10\x03\x12\x1b\n\x17SAMPLING_FIFTEEN_MINUTE\x10\x04\x12\x1a\n\x16SAMPLING_THIRTY_MINUTE\x10\x05\x12\x15\n\x11SAMPLING_ONE_HOUR\x10\x06\x42\xda\x01\n$com.systemathics.apis.type.shared.v1B\rSamplingProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.sampling_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\rSamplingProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_SAMPLING']._serialized_start=86
  _globals['_SAMPLING']._serialized_end=278
# @@protoc_insertion_point(module_scope)
